<template>
    <v-card>
        <Head title="All Payments"/>
        <v-divider/>
        <v-data-table :headers="headers" :items="payments" class="elevation-1">
            <template v-slot:top>
                <v-row justify="space-around" class="mx-2">
                    <v-col>
                        <v-autocomplete v-model="query.customer" :items="customers" dense chips small-chips multiple
                                        solo item-text="name" item-value="id" label="Filter customer" clearable>
                            <template v-slot:item="{item}">
                                <span>{{ item.name }}</span>
                            </template>
                            <template v-bind="attrs" v-slot:selection="{item, attrs}">
                                <v-chip small>
                                    <v-avatar left>
                                        <v-img :src="item.photo_path"></v-img>
                                    </v-avatar>
                                    {{ item.name }}
                                </v-chip>
                            </template>
                        </v-autocomplete>
                    </v-col>
                    <v-col>
                        <v-autocomplete v-model="query.status" :items="statuses" dense chips small-chips multiple solo
                                        item-text="text" item-value="key" label="Filter status" clearable>
                            <template v-slot:item="{item}">
                                <span :style="{color: item.color}">{{ item.text }}</span>
                            </template>
                            <template v-slot:selection="{item}">
                                <v-chip small :color="item.color" dark>{{ item.text }}</v-chip>
                            </template>
                        </v-autocomplete>
                    </v-col>
                    <v-col cols="auto" xs="2">
                        <v-btn type="primary" @click="filterPayments" small class="mt-1">Filter
                            <v-icon small>mdi-filter-outline</v-icon>
                        </v-btn>
                    </v-col>
                </v-row>
            </template>
            <template v-slot:item.customer="{ item }">
                {{ item.order.customer.name }}
            </template>
            <template v-slot:item.amount="{ item }">
                {{ item.amount | number_format }}
            </template>
            <template v-slot:item.date="{ item }">
                {{ item.date | shortDate }}
            </template>
            <template v-slot:item.status="{ item }">
                <v-chip dark x-small class="ma-2" :color="item.status_colour">
                    {{ item.status_text }}
                </v-chip>
            </template>
            <template v-slot:item.type="{ item }">
                <v-chip x-small class="ma-1">
                    {{ item.type }}
                </v-chip>
            </template>
            <template v-slot:item.actions="{ item, index }">
                <v-menu bottom left dense>
                    <template v-slot:activator="{ on, attrs }">
                        <v-btn icon v-bind="attrs" v-on="on">
                            <v-icon>mdi-dots-vertical</v-icon>
                        </v-btn>
                    </template>
                    <v-list dense>
                        <template>
                            <v-list-item link>
                                <v-list-item-title>
                                    <v-icon color="green" small left>mdi-eye-circle-outline</v-icon>
                                    View order
                                </v-list-item-title>
                            </v-list-item>
                            <v-list-item link @click="editItem(item)">
                                <v-list-item-title>
                                    <v-icon color="primary" small left>mdi-email</v-icon>
                                    E-mail receipt
                                </v-list-item-title>
                            </v-list-item>
                            <v-list-item link v-if="item.status === -1">
                                <v-list-item-title @click="deleteItemConfirm(item)">
                                    <v-icon color="red" small>mdi-delete</v-icon>
                                    Delete
                                </v-list-item-title>
                            </v-list-item>
                        </template>
                    </v-list>
                </v-menu>
            </template>
        </v-data-table>
        <compose-email :dialog="dialogEmail" :order="{}" @close="dialogEmail = false"/>
    </v-card>
</template>


<script>
import DashboardLayout from "../../Components/Layouts/Dashboard.vue";
import PaymentLayout from "./Payment.vue";
import ComposeEmail from "../../Components/Email/Dialog/ComposeEmail.vue";


export default {
    name: "PaymentIndex",
    components: {ComposeEmail},
    layout: [DashboardLayout, PaymentLayout],
    data () {
        return {
            error: false,
            rules: [
                value => !!value || 'Please fill this field.',
                value => (value && value.length >= 3) || 'Min 3 characters',
            ],
            dialog: false,
            dialogEmail: false,
            headers: [
                {text: 'Code', align: 'start', value: 'code',},
                {text: 'Amount', value: 'amount'},
                {text: 'Customer', value: 'customer'},
                // {text: 'Period', value: 'period'},
                {text: 'Status', value: 'status', align: 'center'},
                {text: 'Creator', value: 'user.name'},
                {text: 'Order ID', value: 'order.code'},
                {text: 'Date', value: 'date'},
                {text: 'Action', value: 'actions', sortable: false},
            ],
            payments: this.$page.props.payments,
            customers: this.$page.props.customers,
            statuses: [
                {key: 0, text: 'UNPAID', color: 'red'},
                {key: 1, text: 'PAID', color: 'green'},
                {key: -1, text: 'CANCELLED', color: 'gray'}],
            query: {
                lease: [],
                tenant: [],
                status: [],
            },
            editedIndex: -1,
            editedItem: {
                lease: {},
                lease_id: '',
                amount: '',
                status: '',
                count: '',
                date: ''
            }
        }
    },
    computed: {
    },
    watch: {
        dialog(val) {
            val || this.close()
        },
        dialogDelete(val) {
            val || this.closeDelete()
        },
    },
    methods: {
        filterPayments() {
            axios.get(this.$route('payment.filter', {_query: this.query}))
                .then(resp => resp.data)
                .then(data => {
                    this.payments = data.payments
                })
                .catch(this.errHandler)
        },
        downloadPayment(item) {
            axios({
                url: this.$route('payment.download', {payment: item.id}),
                method: 'GET',
                responseType: 'blob'
            })
                .then((response) => {
                    const filename = response.headers['content-disposition'].split('filename=')[1].replace(/^"(.*)"$/, '$1');
                    const blob = new Blob([response.data]);
                    const url = window.URL.createObjectURL(blob);
                    const link = document.createElement('a');
                    link.href = url;
                    link.setAttribute('download', filename);
                    document.body.appendChild(link);
                    link.click();
                });
        },
    },
    mounted() {
    }
}
</script>


<style scoped>

</style>
